==> tabletrack-auto-1.2.35.zip: lang/eng/permissions.php <==
<?php

return [
    'permissions' => [
        'Create Menu' => 'Create Menu',
        'Show Menu' => 'Show Menu',
        'Update Menu' => 'Update Menu',
        'Delete Menu' => 'Delete Menu',
        'Create Menu Item' => 'Create Menu Item',
        'Show Menu Item' => 'Show Menu Item',
        'Update Menu Item' => 'Update Menu Item',
        'Delete Menu Item' => 'Delete Menu Item',
        'Create Item Category' => 'Create Item Category',
        'Show Item Category' => 'Show Item Category',
        'Update Item Category' => 'Update Item Category',
        'Delete Item Category' => 'Delete Item Category',
        'Create Area' => 'Create Area',
        'Show Area' => 'Show Area',
        'Update Area' => 'Update Area',
        'Delete Area' => 'Delete Area',
        'Create Table' => 'Create Table',
        'Show Table' => 'Show Table',
        'Update Table' => 'Update Table',
        'Delete Table' => 'Delete Table',
        'Create Reservation' => 'Create Reservation',
        'Show Reservation' => 'Show Reservation',
        'Update Reservation' => 'Update Reservation',
        'Delete Reservation' => 'Delete Reservation',
        'Manage KOT' => 'Manage KOT',
        'Create Order' => 'Create Order',
        'Show Order' => 'Show Order',
        'Update Order' => 'Update Order',
        'Delete Order' => 'Delete Order',
        'Create Customer' => 'Create Customer',
        'Show Customer' => 'Show Customer',
        'Update Customer' => 'Update Customer',
        'Delete Customer' => 'Delete Customer',
        'Create Staff Member' => 'Create Staff Member',
        'Show Staff Member' => 'Show Staff Member',
        'Update Staff Member' => 'Update Staff Member',
        'Delete Staff Member' => 'Delete Staff Member',
        'Create Delivery Executive' => 'Create Delivery Executive',
        'Show Delivery Executive' => 'Show Delivery Executive',
        'Update Delivery Executive' => 'Update Delivery Executive',
        'Delete Delivery Executive' => 'Delete Delivery Executive',
        'Show Payments' => 'Show Payments',
        'Show Reports' => 'Show Reports',
        'Manage Settings' => 'Manage Settings',
        'Manage Waiter Request' => 'Manage Waiter Request',
        'Create Expense' => 'Create Expenses',
        'Show Expense' => 'Show Expenses',
        'Update Expense' => 'Update Expenses',
        'Delete Expense' => 'Delete Expenses',
        'Create Vendor' => 'Create Vendor',
        'Show Vendor' => 'Show Vendor',
        'Update Vendor' => 'Update Vendor',
        'Delete Vendor' => 'Delete Vendor',

        'Create Inventory Item' => 'Create Inventory Item',
        'Show Inventory Item' => 'Show Inventory Item',
        'Update Inventory Item' => 'Update Inventory Item',
        'Delete Inventory Item' => 'Delete Inventory Item',
        'Create Inventory Movement' => 'Create Inventory Movement',
        'Show Inventory Movement' => 'Show Inventory Movement',
        'Update Inventory Movement' => 'Update Inventory Movement',
        'Delete Inventory Movement' => 'Delete Inventory Movement',
        'Create Unit' => 'Create Unit',
        'Show Unit' => 'Show Unit',
        'Update Unit' => 'Update Unit',
        'Delete Unit' => 'Delete Unit',
        'Create Recipe' => 'Create Recipe',
        'Show Recipe' => 'Show Recipe',
        'Update Recipe' => 'Update Recipe',
        'Delete Recipe' => 'Delete Recipe',
        'Create Purchase Order' => 'Create Purchase Order',
        'Show Purchase Order' => 'Show Purchase Order',
        'Update Purchase Order' => 'Update Purchase Order',
        'Delete Purchase Order' => 'Delete Purchase Order',
        'Show Report' => 'Show Report',
        'Update Settings' => 'Update Settings',
        'Show Inventory Stock' => 'Show Inventory Stock',
        'Show Inventory Report' => 'Show Inventory Report',
        'Update Inventory Settings' => 'Update Inventory Settings',
        'Show Supplier' => 'Show Supplier',
        'Create Supplier' => 'Create Supplier',
        'Update Supplier' => 'Update Supplier',
        'Delete Supplier' => 'Delete Supplier',
        'Create Expense Category' => 'Create Expense Category',
        'Show Expense Category' => 'Show Expense Category',
        'Update Expense Category' => 'Update Expense Category',
        'Delete Expense Category' => 'Delete Expense Category',
    ],

    'modules' => [
        'Menu' => 'Menu',
        'Menu Item' => 'Menu Item',
        'Item Category' => 'Item Category',
        'Area' => 'Area',
        'Table' => 'Table',
        'Reservation' => 'Reservation',
        'KOT' => 'KOT',
        'Order' => 'Order',
        'Customer' => 'Customer',
        'Staff' => 'Staff',
        'Delivery Executive' => 'Delivery Executive',
        'Payment' => 'Payment',
        'Report' => 'Report',
        'Settings' => 'Settings',
        'Waiter Request' => 'Waiter Request',
        'Expense' => 'Expenses',
        'Vendor' => 'Vendor',

        'Inventory' => 'Inventory',
        'Change Branch' => 'Change Branch',
        'Export Report' => 'Export Report',
        'Table Reservation' => 'Table Reservation',
        'Payment Gateway Integration' => 'Payment Gateway Integration',
        'Theme Setting' => 'Theme Setting',
        'Kitchen' => 'Multiple Kitchen',
    ],


];

==> tabletrack-auto-1.2.44.zip: lang/eng/permissions.php <==
<?php

return [
    'permissions' => [
        'Create Menu' => 'Create Menu',
        'Show Menu' => 'Show Menu',
        'Update Menu' => 'Update Menu',
        'Delete Menu' => 'Delete Menu',
        'Create Menu Item' => 'Create Menu Item',
        'Show Menu Item' => 'Show Menu Item',
        'Update Menu Item' => 'Update Menu Item',
        'Delete Menu Item' => 'Delete Menu Item',
        'Create Item Category' => 'Create Item Category',
        'Show Item Category' => 'Show Item Category',
        'Update Item Category' => 'Update Item Category',
        'Delete Item Category' => 'Delete Item Category',
        'Create Area' => 'Create Area',
        'Show Area' => 'Show Area',
        'Update Area' => 'Update Area',
        'Delete Area' => 'Delete Area',
        'Create Table' => 'Create Table',
        'Show Table' => 'Show Table',
        'Update Table' => 'Update Table',
        'Delete Table' => 'Delete Table',
        'Create Reservation' => 'Create Reservation',
        'Show Reservation' => 'Show Reservation',
        'Update Reservation' => 'Update Reservation',
        'Delete Reservation' => 'Delete Reservation',
        'Manage KOT' => 'Manage KOT',
        'Create Order' => 'Create Order',
        'Show Order' => 'Show Order',
        'Update Order' => 'Update Order',
        'Delete Order' => 'Delete Order',
        'Create Customer' => 'Create Customer',
        'Show Customer' => 'Show Customer',
        'Update Customer' => 'Update Customer',
        'Delete Customer' => 'Delete Customer',
        'Create Staff Member' => 'Create Staff Member',
        'Show Staff Member' => 'Show Staff Member',
        'Update Staff Member' => 'Update Staff Member',
        'Delete Staff Member' => 'Delete Staff Member',
        'Create Delivery Executive' => 'Create Delivery Executive',
        'Show Delivery Executive' => 'Show Delivery Executive',
        'Update Delivery Executive' => 'Update Delivery Executive',
        'Delete Delivery Executive' => 'Delete Delivery Executive',
        'Show Payments' => 'Show Payments',
        'Show Reports' => 'Show Reports',
        'Manage Settings' => 'Manage Settings',
        'Manage Waiter Request' => 'Manage Waiter Request',
        'Create Expense' => 'Create Expenses',
        'Show Expense' => 'Show Expenses',
        'Update Expense' => 'Update Expenses',
        'Delete Expense' => 'Delete Expenses',
        'Create Vendor' => 'Create Vendor',
        'Show Vendor' => 'Show Vendor',
        'Update Vendor' => 'Update Vendor',
        'Delete Vendor' => 'Delete Vendor',

        'Create Inventory Item' => 'Create Inventory Item',
        'Show Inventory Item' => 'Show Inventory Item',
        'Update Inventory Item' => 'Update Inventory Item',
        'Delete Inventory Item' => 'Delete Inventory Item',
        'Create Inventory Movement' => 'Create Inventory Movement',
        'Show Inventory Movement' => 'Show Inventory Movement',
        'Update Inventory Movement' => 'Update Inventory Movement',
        'Delete Inventory Movement' => 'Delete Inventory Movement',
        'Create Unit' => 'Create Unit',
        'Show Unit' => 'Show Unit',
        'Update Unit' => 'Update Unit',
        'Delete Unit' => 'Delete Unit',
        'Create Recipe' => 'Create Recipe',
        'Show Recipe' => 'Show Recipe',
        'Update Recipe' => 'Update Recipe',
        'Delete Recipe' => 'Delete Recipe',
        'Create Purchase Order' => 'Create Purchase Order',
        'Show Purchase Order' => 'Show Purchase Order',
        'Update Purchase Order' => 'Update Purchase Order',
        'Delete Purchase Order' => 'Delete Purchase Order',
        'Show Report' => 'Show Report',
        'Update Settings' => 'Update Settings',
        'Show Inventory Stock' => 'Show Inventory Stock',
        'Show Inventory Report' => 'Show Inventory Report',
        'Update Inventory Settings' => 'Update Inventory Settings',
        'Show Supplier' => 'Show Supplier',
        'Create Supplier' => 'Create Supplier',
        'Update Supplier' => 'Update Supplier',
        'Delete Supplier' => 'Delete Supplier',
        'Create Expense Category' => 'Create Expense Category',
        'Show Expense Category' => 'Show Expense Category',
        'Update Expense Category' => 'Update Expense Category',
        'Delete Expense Category' => 'Delete Expense Category',
        'Show Kitchen Place' => 'Show Kitchen Place',
        'Create Kitchen Place' => 'Create Kitchen Place',
        'Update Kitchen Place' => 'Update Kitchen Place',
        'Delete Kitchen Place' => 'Delete Kitchen Place',
    ],

    'modules' => [
        'Menu' => 'Menu',
        'Menu Item' => 'Menu Item',
        'Item Category' => 'Item Category',
        'Area' => 'Area',
        'Table' => 'Table',
        'Reservation' => 'Reservation',
        'KOT' => 'KOT',
        'Order' => 'Order',
        'Customer' => 'Customer',
        'Staff' => 'Staff',
        'Delivery Executive' => 'Delivery Executive',
        'Payment' => 'Payment',
        'Report' => 'Report',
        'Settings' => 'Settings',
        'Waiter Request' => 'Waiter Request',
        'Expense' => 'Expenses',
        'Vendor' => 'Vendor',
        'Inventory' => 'Inventory',
        'Change Branch' => 'Change Branch',
        'Export Report' => 'Export Report',
        'Table Reservation' => 'Table Reservation',
        'Payment Gateway Integration' => 'Payment Gateway Integration',
        'Theme Setting' => 'Theme Setting',
        'Kitchen' => 'Multiple Kitchen',
        'Customer Display' => 'Customer Display',
        'Kiosk' => 'Kiosk',
        'Cash Register' => 'Cash Register',
        'Sms' => 'Sms',
    ],


];
